==> csbase-common-ERAS-1.0.3-sources.jar: csbase/logic/algorithms/parsers/InputFileParameterParser.java <==
package csbase.logic.algorithms.parsers;

import java.util.Collections;
import java.util.List;

import csbase.exception.ParseException;
import csbase.logic.ProjectFileType;
import csbase.logic.algorithms.parameters.FileParameterMode;
import csbase.logic.algorithms.parameters.FileParameterPipeAcceptance;
import csbase.logic.algorithms.parameters.FileURLValue;
import csbase.logic.algorithms.parameters.InputFileParameter;
import csbase.logic.algorithms.parameters.Parameter;
import csbase.logic.algorithms.parameters.ParameterGroup;
import tecgraf.javautils.core.lng.LNG;

/**
 * <p>
 * Analisador de {@link InputFileParameter}.
 * </p>
 *
 * <p>
 * Este parser l os atributos de parmetros do tipo "arquivo de entrada"
 * simples. O elemento corrente do {@link XmlParser analisador de XML} precisa
 * ser um elemento {@link InputFileParameter}.
 * </p>
 *
 */
public class InputFileParameterParser extends
  AbstractFileParameterParser<InputFileParameter> {

  /**
   * <p>
   * O elemento {@value #INPUT_FILE_PARAMETER_ELEMENT}: descreve as propriedades
   * de um {@link InputFileParameter parmetro do tipo arquivo de entrada}.
   * </p>
   * <p>
   *  filho do elemento {@link ParameterGroup}.
   * </p>
   */
  public static final String INPUT_FILE_PARAMETER_ELEMENT =
    "arquivo_de_entrada";

  /**
   * {@inheritDoc}
   */
  @Override
  public InputFileParameter createFileParameter(XmlParser parser, String name,
    String label, String description, boolean isOptional, boolean isVisible,
    String commandLinePattern, String[] types, FileParameterMode mode)
      throws ParseException {

    final boolean sortDefined = parser.hasAttributeValue(
      FILE_PARAMETER_ELEMENT_MUST_SORT_ATTRIBUTE);
    if (sortDefined) {
      boolean mustSort = parser.extractAttributeValueAsBoolean(
        FILE_PARAMETER_ELEMENT_MUST_SORT_ATTRIBUTE,
        FILE_PARAMETER_ELEMENT_MUST_SORT_DEFAULT_VALUE);
      if (mustSort) {
        throw new ParseException(LNG.get(
          "csbase.logic.algorithms.parsers.InputSingleFileNoAttribute")
            + FILE_PARAMETER_ELEMENT_MUST_SORT_ATTRIBUTE);
      }
    }

    FileParameterPipeAcceptance usesPipe = parser
      .extractAttributeValueAsEnumeration(
        FILE_PARAMETER_ELEMENT_CAN_USE_PIPE_ATTRIBUTE,
        FILE_PARAMETER_ELEMENT_CAN_USE_PIPE_DEFAULT_VALUE,
        new FileParameterPipeAcceptanceConverter());

    if(usesPipe != FileParameterPipeAcceptance.FALSE && types.length > 1) {
      throw new ParseException(
        "O valor {0} do atributo {1}  invlido quando se tem mais de um tipo " +
          "de arquivo definido no parmetro.",
        usesPipe, FILE_PARAMETER_ELEMENT_CAN_USE_PIPE_ATTRIBUTE);
    }

    boolean useRootDirectoryAsDefault = parser.extractAttributeValueAsBoolean(
      FILE_PARAMETER_ELEMENT_USE_ROOT_AS_DEFAULT_DIRECTORY_ATTRIBUTE,
      FILE_PARAMETER_ELEMENT_USE_ROOT_AS_DEFAULT_DIRECTORY_DEFAULT_VALUE);
    FileURLValue defaultValue = null;
    if (useRootDirectoryAsDefault) {
      if (mode == FileParameterMode.REGULAR_FILE) {
        throw new ParseException(LNG.get(
          "csbase.logic.algorithms.parsers.InputFileInvalidAttribute"),
          new Object[] {
		  FILE_PARAMETER_ELEMENT_USE_ROOT_AS_DEFAULT_DIRECTORY_ATTRIBUTE });
      }
      defaultValue = new FileURLValue(".", ProjectFileType.DIRECTORY_TYPE);
    }

    boolean useFilter = parser.extractAttributeValueAsBoolean(
      FILE_PARAMETER_ELEMENT_USE_FILTER_ATTRIBUTE,
      FILE_PARAMETER_ELEMENT_USE_FILTER_DEFAULT_VALUE);

    InputFileParameter parameter = new InputFileParameter(name, label,
      description, defaultValue, isOptional, isVisible, commandLinePattern,
      types, mode, usesPipe, useFilter);
    return parameter;
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public List<Class<? extends Parameter>> getParameterTypes() {
    return Collections.singletonList(InputFileParameter.class);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  protected boolean acceptBothCategory() {
    return true;
  }
}

==> csbase-common-ERAS-1.3.1-sources.jar: csbase/logic/algorithms/parsers/InputFileParameterParser.java <==
package csbase.logic.algorithms.parsers;

import java.util.Collections;
import java.util.List;

import csbase.exception.ParseException;
import csbase.logic.ProjectFileType;
import csbase.logic.algorithms.parameters.FileParameterMode;
import csbase.logic.algorithms.parameters.FileParameterPipeAcceptance;
import csbase.logic.algorithms.parameters.FileURLValue;
import csbase.logic.algorithms.parameters.InputFileParameter;
import csbase.logic.algorithms.parameters.Parameter;
import csbase.logic.algorithms.parameters.ParameterGroup;
import tecgraf.javautils.core.lng.LNG;

/**
 * <p>
 * Analisador de {@link InputFileParameter}.
 * </p>
 *
 * <p>
 * Este parser l os atributos de parmetros do tipo "arquivo de entrada"
 * simples. O elemento corrente do {@link XmlParser analisador de XML} precisa
 * ser um elemento {@link InputFileParameter}.
 * </p>
 *
 */
public class InputFileParameterParser extends
  AbstractFileParameterParser<InputFileParameter> {

  /**
   * <p>
   * O elemento {@value #INPUT_FILE_PARAMETER_ELEMENT}: descreve as propriedades
   * de um {@link InputFileParameter parmetro do tipo arquivo de entrada}.
   * </p>
   * <p>
   *  filho do elemento {@link ParameterGroup}.
   * </p>
   */
  public static final String INPUT_FILE_PARAMETER_ELEMENT =
    "arquivo_de_entrada";

  /**
   * <p>
   * Atributo do elemento {@value #INPUT_FILE_PARAMETER_ELEMENT} que indica se o
   * arquivo de entrada deve ser utilizado para carregar o valor de outros
   * parmetros. Essa carga  feita no cliente.
   */
  public static final String INPUT_FILE_PARAMETER_USE_TO_LOAD_PARAM = "carregar_parametros";

  /**
   * Valor padro do atributo {@value #INPUT_FILE_PARAMETER_USE_TO_LOAD_PARAM}.
   */
  public static final boolean INPUT_FILE_PARAMETER_USE_TO_LOAD_PARAM_DEFAULT_VALUE = false;
  /**
   * {@inheritDoc}
   */
  @Override
  public InputFileParameter createFileParameter(XmlParser parser, String name,
    String label, String description, boolean isOptional, boolean isVisible,
    String commandLinePattern, String[] types, FileParameterMode mode)
      throws ParseException {

    final boolean sortDefined = parser.hasAttributeValue(
      FILE_PARAMETER_ELEMENT_MUST_SORT_ATTRIBUTE);
    if (sortDefined) {
      boolean mustSort = parser.extractAttributeValueAsBoolean(
        FILE_PARAMETER_ELEMENT_MUST_SORT_ATTRIBUTE,
        FILE_PARAMETER_ELEMENT_MUST_SORT_DEFAULT_VALUE);
      if (mustSort) {
        throw new ParseException(LNG.get(
          "csbase.logic.algorithms.parsers.InputSingleFileNoAttribute")
            + FILE_PARAMETER_ELEMENT_MUST_SORT_ATTRIBUTE);
      }
    }

    FileParameterPipeAcceptance usesPipe = parser
      .extractAttributeValueAsEnumeration(
        FILE_PARAMETER_ELEMENT_CAN_USE_PIPE_ATTRIBUTE,
        FILE_PARAMETER_ELEMENT_CAN_USE_PIPE_DEFAULT_VALUE,
        new FileParameterPipeAcceptanceConverter());

    if(usesPipe != FileParameterPipeAcceptance.FALSE && types.length > 1) {
      throw new ParseException(
        "O valor {0} do atributo {1}  invlido quando se tem mais de um tipo " +
          "de arquivo definido no parmetro.",
        usesPipe, FILE_PARAMETER_ELEMENT_CAN_USE_PIPE_ATTRIBUTE);
    }

    boolean useRootDirectoryAsDefault = parser.extractAttributeValueAsBoolean(
      FILE_PARAMETER_ELEMENT_USE_ROOT_AS_DEFAULT_DIRECTORY_ATTRIBUTE,
      FILE_PARAMETER_ELEMENT_USE_ROOT_AS_DEFAULT_DIRECTORY_DEFAULT_VALUE);
    FileURLValue defaultValue = null;
    if (useRootDirectoryAsDefault) {
      if (mode == FileParameterMode.REGULAR_FILE) {
        throw new ParseException(LNG.get(
          "csbase.logic.algorithms.parsers.InputFileInvalidAttribute"),
          new Object[] {
		  FILE_PARAMETER_ELEMENT_USE_ROOT_AS_DEFAULT_DIRECTORY_ATTRIBUTE });
      }
      defaultValue = new FileURLValue(".", ProjectFileType.DIRECTORY_TYPE);
    }

    boolean useFilter = parser.extractAttributeValueAsBoolean(
      FILE_PARAMETER_ELEMENT_USE_FILTER_ATTRIBUTE,
      FILE_PARAMETER_ELEMENT_USE_FILTER_DEFAULT_VALUE);

    boolean useToLoadParam = parser.extractAttributeValueAsBoolean(
        INPUT_FILE_PARAMETER_USE_TO_LOAD_PARAM,
        INPUT_FILE_PARAMETER_USE_TO_LOAD_PARAM_DEFAULT_VALUE);

    InputFileParameter parameter = new InputFileParameter(name, label,
      description, defaultValue, isOptional, isVisible, commandLinePattern,
      types, mode, usesPipe, useFilter, useToLoadParam);
    return parameter;
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public List<Class<? extends Parameter>> getParameterTypes() {
    return Collections.singletonList(InputFileParameter.class);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  protected boolean acceptBothCategory() {
    return true;
  }
}
